import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  format,
  line,
  area,
  curveBasis,
} from 'd3';

const svg = d3.select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

const render = (data) => {
  const xValue = (d) => d.City;
  const yValue = (d) => d.Population;

  const margin = {
    top: 20,
    right: 20,
    bottom: 70,
    left: 40,
  };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  const xScale = d3
    .scaleBand()
    .domain(data.map(xValue))
    .range([0, innerWidth])
    .padding(0.1);

  const yScale = d3
    .scaleLinear()
    .domain([0, d3.max(data, yValue)])
    .range([innerHeight, 0]);

  const g = svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  g.selectAll('rect')
    .data(data)
    .enter()
    .append('rect')
    .attr('class', 'bar')
    .attr('x', (d) => xScale(xValue(d)))
    .attr('y', (d) => yScale(yValue(d)))
    .attr('height', (d) => innerHeight - yScale(yValue(d)))
    .attr('width', xScale.bandwidth());

  g.append('g').call(d3.axisLeft(yScale));
  g.append('g')
    .call(d3.axisBottom(xScale))
    .attr('transform', `translate(0,${innerHeight})`);
};

d3.csv(
  'https://gist.githubusercontent.com/NandithaSura/f39fe93f7331b99f43ae97ec06c64857/raw/0b15f0161bcf7de31deb5d03f271bd0e3a32a55e/prediction.csv',
).then((data) => {
  data.forEach((d) => {
    d.Population = +d.Population;
  });
  render(data);
});
